@@ -1,12 +1,12 @@
 package File::Sticker::Scribe;
-$File::Sticker::Scribe::VERSION = '4.101';
+$File::Sticker::Scribe::VERSION = '4.301';
 =head1 NAME
 
 File::Sticker::Scribe - read, write and standardize meta-data from files
 
 =head1 VERSION
 
-version 4.101
+version 4.301
 
 =head1 SYNOPSIS
 
@@ -104,6 +104,24 @@ sub init {
     }
     $self->{file_magic} = File::LibMagic->new(follow_symlinks=>1);
 
+    # If we want to read all, then create wanted fields if we don't have them
+    if ($self->{read_all}
+            and !(exists $self->{wanted_fields}
+                and defined $self->{wanted_fields})
+    )
+    {
+        $self->{wanted_fields} = {};
+        my $known = $self->known_fields();
+        foreach my $field (keys %{$known})
+        {
+            $self->{wanted_fields}->{$field} = $known->{$field};
+        }
+        my $readonly = $self->readonly_fields();
+        foreach my $field (keys %{$readonly})
+        {
+            $self->{wanted_fields}->{$field} = $readonly->{$field};
+        }
+    }
     # Set the writable fields from the known and readonly fields
     if (exists $self->{wanted_fields}
             and defined $self->{wanted_fields})
